%global base_name    xdg-desktop-portal-kde
# Version required for Session support.
%global xdg_desktop_portal_version 0.5
%global flatpak_version 0.8.7

Name:           xdg-desktop-portal-kde
Summary:        Backend implementation for xdg-desktop-portal using Qt/KF5
Version:        5.12.7
Release:        1.1%{?dist}

License:        GPLv2+
URL:            https://cgit.kde.org/%{base_name}.git

%global revision %(echo %{version} | cut -d. -f3)
%if %{revision} >= 50
%global stable unstable
%else
%global stable stable
%endif
Source0:        http://download.kde.org/%{stable}/plasma/%{version}/%{base_name}-%{version}.tar.xz

BuildRequires:  extra-cmake-modules
BuildRequires:  kf5-rpm-macros
BuildRequires:  qt5-qtbase-devel
BuildRequires:  qt5-qtbase-private-devel
# libQt5PrintSupport.so.5(Qt_5_PRIVATE_API)(64bit)
#%{?_qt5:Requires: %{_qt5}%{?_isa} = %{_qt5_version}}

#BuildRequires:  glib2-devel
#BuildRequires:  libepoxy-devel
#BuildRequires:  mesa-libgbm-devel
#BuildRequires:  pipewire-devel

BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5Notifications)
#BuildRequires:  cmake(KF5Wayland)
#BuildRequires:  cmake(KF5WidgetsAddons)

BuildRequires:  pkgconfig(xdg-desktop-portal) >= %{xdg_desktop_portal_version}
BuildRequires:  flatpak >= %{flatpak_version}


Requires:       xdg-desktop-portal >= %{xdg_desktop_portal_version}
Requires:       flatpak >= %{flatpak_version}

%if 0%{?fedora} && 0%{?fedora} >= 28
Supplements: (plasma-desktop and (flatpak or snapd))
%endif

%description
A backend implementation for xdg-desktop-portal that is using Qt/KF5 and various
pieces of KDE infrastructure.


%prep
%autosetup -n "%{base_name}-%{version}" -p1


%build
mkdir "%{_target_platform}"
pushd "%{_target_platform}"
%{cmake_kf5} ..
popd

%make_build -C "%{_target_platform}"


%install
make install/fast DESTDIR="%{buildroot}" -C "%{_target_platform}"

%find_lang "%{name}"


%post -p /sbin/ldconfig

%files -f "%{name}.lang"
%license COPYING
%{_libexecdir}/%{name}
%{_datadir}/dbus-1/services/org.freedesktop.impl.portal.desktop.kde.service
%{_datadir}/xdg-desktop-portal/portals/kde.portal


%changelog
* Wed Nov 28 2018 Tomasz Tomasik <scx.mail@gmail.com> - 5.12.7-1.1
- Update requirements
- Rebuilt for EL7

* Fri Nov 09 2018 Rex Dieter <rdieter@fedoraproject.org> - 5.12.7-1
- 5.12.7

* Wed Jun 27 2018 Rex Dieter <rdieter@fedoraproject.org> - 5.12.6-1
- 5.12.6

* Fri Jun 15 2018 Rex Dieter <rdieter@fedoraproject.org> - 5.12.5-1.1
- branch rebuild (qt5)

* Tue May 01 2018 Rex Dieter <rdieter@fedoraproject.org> - 5.12.5-1
- 5.12.5

* Tue Mar 27 2018 Rex Dieter <rdieter@fedoraproject.org> - 5.12.4-1
- 5.12.4

* Tue Mar 06 2018 Rex Dieter <rdieter@fedoraproject.org> - 5.12.3-1
- 5.12.3

* Wed Feb 21 2018 Jan Grulich <jgrulich@redhat.com> - 5.12.2-1
- 5.12.2

* Tue Feb 13 2018 Jan Grulich <jgrulich@redhat.com> - 5.12.1-1
- 5.12.1

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 5.12.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Feb 02 2018 Jan Grulich <jgrulich@redhat.com> - 5.12.0-1
- 5.12.0

* Mon Jan 15 2018 Jan Grulich <jgrulich@redhat.com> - 5.11.95-1
- 5.11.95

* Tue Jan 02 2018 Rex Dieter <rdieter@fedoraproject.org> - 5.11.5-1
- 5.11.5

* Sun Dec 31 2017 Rex Dieter <rdieter@fedoraproject.org> - 5.11.4-2
- rebuild (qt-5.10.0)

* Thu Nov 30 2017 Martin Kyral <martin.kyral@gmail.com> - 5.11.4-1
- 5.11.4

* Mon Nov 27 2017 Rex Dieter <rdieter@fedoraproject.org> - 5.11.3-2
- rebuild (qt5)

* Wed Nov 08 2017 Rex Dieter <rdieter@fedoraproject.org> - 5.11.3-1
- 5.11.3

* Wed Oct 25 2017 Martin Kyral <martin.kyral@gmail.com> - 5.11.2-1
- 5.11.2

* Tue Oct 17 2017 Rex Dieter <rdieter@fedoraproject.org> - 5.11.1-1
- 5.11.1

* Wed Oct 11 2017 Martin Kyral <martin.kyral@gmail.com> - 5.11.0-1
- 5.11.0

* Wed Oct 11 2017 Rex Dieter <rdieter@fedoraproject.org> - 5.10.5-2
- BR: qt5-qtbase-private-devel, drop needless scriptlet, use %%autosetup, cosmetics

* Thu Aug 24 2017 Rex Dieter <rdieter@fedoraproject.org> - 5.10.5-1
- 5.10.5

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 5.10.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 5.10.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Jul 21 2017 Rex Dieter <rdieter@fedoraproject.org> - 5.10.4-1
- 5.10.4

* Wed Jun 28 2017 Martin Kyral <martin.kyral@gmail.com> - 5.10.3-1
- 5.10.3

* Wed Jun 14 2017 Martin Kyral <martin.kyral@gmail.com> - 5.10.2-1
- 5.10.2

* Wed May 31 2017 Martin Kyral <martin.kyral@gmail.com> - 5.10.0-1
- 5.10.0 (new package)
